@@ -28,7 +28,7 @@ class ConfigDebug(Config):
     )
     git_quiet = ParamCreator.create_bool(
         help_string="add --quiet when running git?",
-        default=True,
+        default=False,
     )
     stats = ParamCreator.create_bool(
         help_string="show statistics are the end?",
@@ -42,9 +42,13 @@ class ConfigDebug(Config):
 
 class ConfigGrep(Config):
     """
-    Parameters for pymultigit
+    Parameters for the grep command
     """
 
     regexp = ParamCreator.create_str(
         help_string="what regexp to look for?",
     )
+    files = ParamCreator.create_str_or_none(
+        help_string="what regexp to look for?",
+        default=None,
+    )
