@@ -18,9 +18,9 @@ def projects(sort: bool) -> Generator[Tuple[str, str], None, None]:
     repos_list = glob.glob('*/.git')
     if sort:
         repos_list.sort()
-    if len(repos_list) == 0:
-        print('no git repos here', file=sys.stderr)
-        sys.exit(1)
+    # if len(repos_list) == 0:
+    #    print('no git repos here', file=sys.stderr)
+    #    sys.exit(1)
     for x in repos_list:
         yield os.path.dirname(x), os.path.dirname(x)
 
@@ -125,14 +125,18 @@ def do_pull(project_name: str, project_dir: str) -> int:
     return subprocess.call(args)
 
 
-def do_grep(project_name: str, project_dir: str) -> None:
-    fake_use(project_name, project_dir)
-    args = ['git', 'grep', ConfigGrep.regexp]
+def do_grep(_project_name: str, project_dir: str) -> None:
+    args = ['git', 'grep']
     if ConfigDebug.git_verbose:
         args.append('--verbose')
     if ConfigDebug.git_quiet:
         args.append('--quiet')
-    # return subprocess.call(args)
+    args.append(ConfigGrep.regexp)
+    if ConfigGrep.files is not None:
+        args.extend([
+            "--",
+            ConfigGrep.files
+        ])
     with subprocess.Popen(
         args,
         shell=False,
