@@ -1,5 +1,5 @@
 """ version which can be consumed from within the module """
-VERSION_STR = "0.0.44"
-DESCRIPTION = "pymultigit is a command to help you deal with multiple git repositories"
+VERSION_STR = "0.0.45"
+DESCRIPTION = "Help you deal with multiple git repositories"
 APP_NAME = "pymultigit"
 LOGGER_NAME = "pymultigit"
